==> huaweicloudsdkcts-3.1.116-py2.py3-none-any.whl: huaweicloudsdkcts/v3/model/list_operations_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListOperationsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'operations': 'list[ListOperation]'
    }

    attribute_map = {
        'operations': 'operations'
    }

    def __init__(self, operations=None):
        """ListOperationsResponse

        The model defined in huaweicloud sdk

        :param operations: 全量云服务的操作事件列表。
        :type operations: list[:class:`huaweicloudsdkcts.v3.ListOperation`]
        """
        
        super(ListOperationsResponse, self).__init__()

        self._operations = None
        self.discriminator = None

        if operations is not None:
            self.operations = operations

    @property
    def operations(self):
        """Gets the operations of this ListOperationsResponse.

        全量云服务的操作事件列表。

        :return: The operations of this ListOperationsResponse.
        :rtype: list[:class:`huaweicloudsdkcts.v3.ListOperation`]
        """
        return self._operations

    @operations.setter
    def operations(self, operations):
        """Sets the operations of this ListOperationsResponse.

        全量云服务的操作事件列表。

        :param operations: The operations of this ListOperationsResponse.
        :type operations: list[:class:`huaweicloudsdkcts.v3.ListOperation`]
        """
        self._operations = operations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListOperationsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcts-3.1.156-py2.py3-none-any.whl: huaweicloudsdkcts/v3/model/list_operations_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListOperationsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'operations': 'list[ListOperation]'
    }

    attribute_map = {
        'operations': 'operations'
    }

    def __init__(self, operations=None):
        r"""ListOperationsResponse

        The model defined in huaweicloud sdk

        :param operations: 全量云服务的操作事件列表。
        :type operations: list[:class:`huaweicloudsdkcts.v3.ListOperation`]
        """
        
        super(ListOperationsResponse, self).__init__()

        self._operations = None
        self.discriminator = None

        if operations is not None:
            self.operations = operations

    @property
    def operations(self):
        r"""Gets the operations of this ListOperationsResponse.

        全量云服务的操作事件列表。

        :return: The operations of this ListOperationsResponse.
        :rtype: list[:class:`huaweicloudsdkcts.v3.ListOperation`]
        """
        return self._operations

    @operations.setter
    def operations(self, operations):
        r"""Sets the operations of this ListOperationsResponse.

        全量云服务的操作事件列表。

        :param operations: The operations of this ListOperationsResponse.
        :type operations: list[:class:`huaweicloudsdkcts.v3.ListOperation`]
        """
        self._operations = operations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListOperationsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
